@@ -3,10 +3,10 @@
  *
  * Copyright (C) 2010 Creytiv.com
  */
+#include <stdio.h>
 
-
-#ifndef VERSION
-#define VERSION "?"
+#ifndef RE_VERSION
+#define RE_VERSION "?"
 #endif
 
 /**
@@ -32,14 +32,15 @@
 #endif
 
 struct re_printf;
-int  sys_rel_get(uint32_t *rel, uint32_t *maj, uint32_t *min,
-		 uint32_t *patch);
+struct mbuf;
+
 int  sys_kernel_get(struct re_printf *pf, void *unused);
 int  sys_build_get(struct re_printf *pf, void *unused);
 const char *sys_arch_get(void);
 const char *sys_os_get(void);
 const char *sys_libre_version_get(void);
 const char *sys_username(void);
+int sys_getenv(char **env, const char *name);
 int sys_coredump_set(bool enable);
 int sys_daemon(void);
 void sys_usleep(unsigned int us);
@@ -59,7 +60,6 @@ uint64_t sys_ntohll(uint64_t v);
 
 
 /* Random */
-void     rand_init(void);
 uint16_t rand_u16(void);
 uint32_t rand_u32(void);
 uint64_t rand_u64(void);
@@ -71,3 +71,10 @@ void     rand_bytes(uint8_t *p, size_t size);
 /* File-System */
 int  fs_mkdir(const char *path, uint16_t mode);
 int  fs_gethome(char *path, size_t sz);
+bool fs_isdir(const char *path);
+bool fs_isfile(const char *file);
+int  fs_fopen(FILE **fp, const char *file, const char *mode);
+int  fs_fread(struct mbuf **mbp, const char *path);
+
+void fs_stdio_hide(void);
+void fs_stdio_restore(void);
